@@ -54,27 +54,28 @@ def run_pipeline(config, start_module_name):
 
     # make instance of the QC class
     qc = components.QC(
-        in_dir=config.in_dir,
-        out_dir=config.out_dir,
-        random_sample_size=config.random_sample_size,
-        mask_object=config.mask_object,
-        sample_conditions=config.sample_conditions,
-        sample_abbreviations=config.sample_abbreviations,
-        sample_statuses=config.sample_statuses,
-        sample_replicates=config.sample_replicates,
-        samples_to_exclude=config.samples_to_exclude,
-        markers_to_exclude=config.markers_to_exclude,
+        inDir=config.inDir,
+        outDir=config.outDir,
+        randomSampleSize=config.randomSampleSize,
+        maskObject=config.maskObject,
+        sampleConditions=config.sampleConditions,
+        sampleAbbreviations=config.sampleAbbreviations,
+        sampleStatuses=config.sampleStatuses,
+        sampleReplicates=config.sampleReplicates,
+        samplesToExclude=config.samplesToExclude,
+        markersToExclude=config.markersToExclude,
 
-        view_sample=config.view_sample,
-
-        delint_mode=config.delint_mode,
-        show_ab_channels=config.show_ab_channels,
+        delintMode=config.delintMode,
+        showAbChannels=config.showAbChannels,
 
         cutoffAxis=config.cutoffAxis,
-        log_ratio_rnge=config.log_ratio_rnge,
+        logRatioRnge=config.logRatioRnge,
 
         hexbins=config.hexbins,
-        hexbin_grid_size=config.hexbin_grid_size,
+        hexbinGridSize=config.hexbinGridSize,
+
+        metaQC=config.metaQC,
+        reclassCutoff=config.reclassCutoff,
 
         channelExclusionsPCA=config.channelExclusionsPCA,
         samplesToRemovePCA=config.samplesToRemovePCA,
@@ -85,30 +86,47 @@ def run_pipeline(config, start_module_name):
         distanceCutoff=config.distanceCutoff,
         samplesToSilhouette=config.samplesToSilhouette,
 
+        embeddingAlgorithmQC=config.embeddingAlgorithmQC,
         embeddingAlgorithm=config.embeddingAlgorithm,
+        channelExclusionsClusteringQC=config.channelExclusionsClusteringQC,
         channelExclusionsClustering=config.channelExclusionsClustering,
         normalizeTissueCounts=config.normalizeTissueCounts,
+        samplesToRemoveClusteringQC=config.samplesToRemoveClusteringQC,
         samplesToRemoveClustering=config.samplesToRemoveClustering,
+        fracForEmbeddingQC=config.fracForEmbeddingQC,
         fracForEmbedding=config.fracForEmbedding,
+        dimensionEmbeddingQC=config.dimensionEmbeddingQC,
         dimensionEmbedding=config.dimensionEmbedding,
 
+        perplexityQC=config.perplexityQC,
         perplexity=config.perplexity,
+        earlyExaggerationQC=config.earlyExaggerationQC,
         earlyExaggeration=config.earlyExaggeration,
+        learningRateTSNEQC=config.learningRateTSNEQC,
         learningRateTSNE=config.learningRateTSNE,
+        metricQC=config.metricQC,
         metric=config.metric,
-        random_state=config.random_state,
+        randomStateQC=config.randomStateQC,
+        randomState=config.randomState,
 
+        nNeighborsQC=config.nNeighborsQC,
         nNeighbors=config.nNeighbors,
+        learningRateUMAPQC=config.learningRateUMAPQC,
         learningRateUMAP=config.learningRateUMAP,
+        minDistQC=config.minDistQC,
         minDist=config.minDist,
+        repulsionStrengthQC=config.repulsionStrengthQC,
         repulsionStrength=config.repulsionStrength,
 
         controlGroups=config.controlGroups,
         denominatorCluster=config.denominatorCluster,
         FDRCorrection=config.FDRCorrection,
 
+        viewSample=config.viewSample,
+
         numThumbnails=config.numThumbnails,
         squareWindowDimension=config.squareWindowDimension,
+        segOutlines=config.segOutlines,
 
         bonferroniCorrection=config.bonferroniCorrection,
 
